@@ -7,15 +7,11 @@ class User(Document):
     def is_active(self):
         """Fake function. Always returns True"""
         return True
-
+    
     def is_authenticated(self):
         """Links to self.is_superuser"""
         return '_id' in self
-
-    def is_staff(self):
-        """Fake function. Always returns True"""
-        return self.is_staff
-
+    
     def get_and_delete_messages(self):
         return None
 
